@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# kate: space-indent on; indent-width 4; replace-tabs on;
 # Django settings for mumble_django project.
 
 """
@@ -53,10 +54,28 @@ MUMBLE_DJANGO_ROOT = None                                      ##
 #################################################################
 #################################################################
 
+# Who will receive emails on errors?
+ADMINS = (
+    # ('Your Name', 'your_email@domain.com'),
+)
 
-from os.path import join, dirname, abspath, exists
-if not MUMBLE_DJANGO_ROOT or not exists( MUMBLE_DJANGO_ROOT ):
-	MUMBLE_DJANGO_ROOT = dirname(dirname(abspath(__file__)));
+# Show debug information on errors?
+# If you want to file a bug report, please enable this option.
+DEBUG = True
+
+# Local time zone for this installation. Choices can be found here:
+# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
+# although not all choices may be available on all operating systems.
+# If running in a Windows environment this must be set to the same as your
+# system time zone.
+TIME_ZONE = 'Europe/Berlin'
+
+# Language code for this installation. All choices can be found here:
+# http://www.i18nguy.com/unicode/language-identifiers.html
+LANGUAGE_CODE = 'en-us'
+
+# The Theme to use. None for the builtin theme.
+THEME = None
 
 # URL Template for constructing Gravatars.
 GRAVATAR_URL = 'http://www.gravatar.com/avatar/%(hash)s.jpg?d=monsterid&s=%(size)d'
@@ -75,9 +94,6 @@ DEFAULT_FROM_EMAIL = "webmaster@localhost"
 # Length of the account activation period, in days.
 ACCOUNT_ACTIVATION_DAYS = 30
 
-# Default mumble port. If your server runs under this port, it will not be included in the links in the Channel Viewer.
-MUMBLE_DEFAULT_PORT = 64738
-
 # Should subchannels be shown, even if there are no players in them?
 SHOW_EMPTY_SUBCHANS = False
 
@@ -95,8 +111,8 @@ PROTECTED_MODE = False
 # stolen they could easily take over the server. (So make sure the password can't be easily
 # guessed, use at least over 9000 letters, blah blah.)
 # This feature is only available if PROTECTED_MODE is not active.
-ALLOW_ACCOUNT_LINKING = True		# Allow linking in general?
-ALLOW_ACCOUNT_LINKING_ADMINS = False	# Allow linking for Admin accounts?
+ALLOW_ACCOUNT_LINKING = True          # Allow linking in general?
+ALLOW_ACCOUNT_LINKING_ADMINS = False  # Allow linking for Admin accounts?
 
 # Warning and Critical levels for the Munin plugin. These will be multiplied with the
 # server instance's slot count to calculate the real levels.
@@ -107,8 +123,29 @@ MUNIN_TITLE    = 'Mumble Users'
 # see <http://munin.projects.linpro.no/wiki/graph_category_list> for a list of valid categories.
 MUNIN_CATEGORY = 'network'
 
-# Database settings for Mumble-Django's database. These do NOT need to point to Murmur's database,
-# Mumble-Django should use its own!
+
+###################################################################
+##                                                               ##
+##  The following settings normally do not require changes, and  ##
+##  you should only change them if you know what you're doing.   ##
+##                                                               ##
+###################################################################
+
+from os.path import join, dirname, abspath, exists
+if not MUMBLE_DJANGO_ROOT or not exists( MUMBLE_DJANGO_ROOT ):
+    MUMBLE_DJANGO_ROOT = dirname(dirname(abspath(__file__)))
+
+# Default mumble port. If your server runs under this port, it will not be
+# included in the links in the Channel Viewer.
+MUMBLE_DEFAULT_PORT = 64738
+
+if not MUMBLE_DJANGO_URL:
+    MUMBLE_DJANGO_URL = '/'
+elif MUMBLE_DJANGO_URL[-1] != '/':
+    MUMBLE_DJANGO_URL = MUMBLE_DJANGO_URL + '/'
+
+# Database settings for Mumble-Django's database. These do NOT need to point
+# to Murmur's database, Mumble-Django should use its own!
 DATABASE_ENGINE = 'sqlite3'
 DATABASE_NAME = join( MUMBLE_DJANGO_ROOT, 'db', 'mumble-django.db3' )
 DATABASE_USER = ''
@@ -116,123 +153,124 @@ DATABASE_PASSWORD = ''
 DATABASE_HOST = ''
 DATABASE_PORT = ''
 
+# Email settings. only change if the defaults don't work
+#EMAIL_HOST = "localhost"
+#EMAIL_PORT = 25
+#EMAIL_HOST_USER = ""
+#EMAIL_HOST_PASSWORD = ""
+#EMAIL_USE_TLS = True
 
-# Show debug information on errors?
-DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
-ADMINS = (
-    # ('Your Name', 'your_email@domain.com'),
-)
-
 MANAGERS = ADMINS
 
-# Local time zone for this installation. Choices can be found here:
-# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
-# although not all choices may be available on all operating systems.
-# If running in a Windows environment this must be set to the same as your
-# system time zone.
-TIME_ZONE = 'Europe/Berlin'
-
-# Language code for this installation. All choices can be found here:
-# http://www.i18nguy.com/unicode/language-identifiers.html
-LANGUAGE_CODE = 'en-us'
-
 SITE_ID = 1
 
 # If you set this to False, Django will make some optimizations so as not
 # to load the internationalization machinery.
 USE_I18N = True
 
-
 # Absolute path to the directory that holds media.
 MEDIA_ROOT = join( MUMBLE_DJANGO_ROOT, 'htdocs' )
 
 # URL that handles the media served from MEDIA_ROOT.
-MEDIA_URL = MUMBLE_DJANGO_URL+'static/'
+MEDIA_URL = MUMBLE_DJANGO_URL + 'static/'
+
+## URL to static files of the currently active theme
+THEME_URL = '%sstatic/themes/%s/' % ( MUMBLE_DJANGO_URL, THEME )
 
 # URL prefix for admin media -- CSS, JavaScript and images.
-ADMIN_MEDIA_PREFIX = MUMBLE_DJANGO_URL+'media/'
+ADMIN_MEDIA_PREFIX = MUMBLE_DJANGO_URL + 'media/'
 
 # URL to the login view
-LOGIN_URL = MUMBLE_DJANGO_URL + 'accounts/login';
-LOGIN_REDIRECT_URL = MUMBLE_DJANGO_URL + 'accounts/profile';
+LOGIN_URL = MUMBLE_DJANGO_URL + 'accounts/login'
+LOGIN_REDIRECT_URL = MUMBLE_DJANGO_URL + 'accounts/profile'
 
 
 # Automatically generate a .secret.txt file containing the SECRET_KEY.
 # Shamelessly stolen from ByteFlow: <http://www.byteflow.su>
 try:
-	SECRET_KEY
+    SECRET_KEY
 except NameError:
-	SECRET_FILE = join(MUMBLE_DJANGO_ROOT, '.secret.txt')
-	try:
-		SECRET_KEY = open(SECRET_FILE).read().strip()
-	except IOError:
-		try:
-			from random import choice
-			SECRET_KEY = ''.join([choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)])
-			secret = file(SECRET_FILE, 'w')
-			secret.write(SECRET_KEY)
-			secret.close()
-		except IOError:
-			Exception('Please create a %s file with random characters to generate your secret key!' % SECRET_FILE)
+    SECRET_FILE = join(MUMBLE_DJANGO_ROOT, '.secret.txt')
+    try:
+        SECRET_KEY = open(SECRET_FILE).read().strip()
+    except IOError:
+        try:
+            from random import choice
+            SECRET_KEY = ''.join([choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)])
+            secret = file(SECRET_FILE, 'w')
+            secret.write(SECRET_KEY)
+            secret.close()
+        except IOError:
+            Exception('Please create a %s file with random characters to generate your secret key!' % SECRET_FILE)
 
 
 # List of callables that know how to import templates from various sources.
 TEMPLATE_LOADERS = (
-	'django.template.loaders.filesystem.load_template_source',
-	'django.template.loaders.app_directories.load_template_source',
+    'django.template.loaders.filesystem.load_template_source',
+    'django.template.loaders.app_directories.load_template_source',
 )
 
 MIDDLEWARE_CLASSES = (
-	'django.middleware.common.CommonMiddleware',
-	'django.contrib.sessions.middleware.SessionMiddleware',
-	'django.middleware.locale.LocaleMiddleware',
-	'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.middleware.common.CommonMiddleware',
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.middleware.locale.LocaleMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
 )
 
 ROOT_URLCONF = 'pyweb.urls'
 
-TEMPLATE_DIRS = (
-	# Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
-	# Always use forward slashes, even on Windows.
-	# Don't forget to use absolute paths, not relative paths.
-	join( MUMBLE_DJANGO_ROOT, 'pyweb', 'templates' ),
-)
+if THEME:
+	TEMPLATE_DIRS = [ join( MUMBLE_DJANGO_ROOT, 'themes', THEME ) ]
+else:
+	TEMPLATE_DIRS = []
 
-TEMPLATE_CONTEXT_PROCESSORS = (
-	"django.core.context_processors.auth",
-	"django.core.context_processors.debug",
-	"django.core.context_processors.i18n",
-	"django.core.context_processors.media",
-	'processors.installed_apps',
-)
+TEMPLATE_DIRS.extend((
+    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
+    # Always use forward slashes, even on Windows.
+    # Don't forget to use absolute paths, not relative paths.
+    join( MUMBLE_DJANGO_ROOT, 'pyweb', 'templates' ),
+))
+
+TEMPLATE_CONTEXT_PROCESSORS = [
+    "django.core.context_processors.auth",
+    "django.core.context_processors.debug",
+    "django.core.context_processors.i18n",
+    "django.core.context_processors.media",
+    'processors.installed_apps',
+    'processors.mumble_version',
+]
+
+if THEME:
+    TEMPLATE_CONTEXT_PROCESSORS.append('processors.theme_url')
 
 TEST_RUNNER = 'mumble.testrunner.run_tests'
-TEST_MURMUR_LAB_DIR   = join( dirname(MUMBLE_DJANGO_ROOT), 'murmur' );
-TEST_MURMUR_FILES_DIR = join( MUMBLE_DJANGO_ROOT, 'testdata' );
+TEST_MURMUR_LAB_DIR   = join( dirname(MUMBLE_DJANGO_ROOT), 'murmur' )
+TEST_MURMUR_FILES_DIR = join( MUMBLE_DJANGO_ROOT, 'testdata' )
 
-CONVERSIONSQL_ROOT = join( MUMBLE_DJANGO_ROOT, "pyweb", "mumble", "conversionsql" );
+CONVERSIONSQL_ROOT = join( MUMBLE_DJANGO_ROOT, "pyweb", "mumble", "conversionsql" )
 
 INSTALLED_APPS = [
-	'django.contrib.auth',
-	'django.contrib.admin',
-	'django.contrib.contenttypes',
-	'django.contrib.sessions',
-	'django.contrib.sites',
-	'registration',
-	'mumble',
+    'django.contrib.auth',
+    'django.contrib.admin',
+    'django.contrib.contenttypes',
+    'django.contrib.sessions',
+    'django.contrib.sites',
+    'registration',
+    'mumble',
 ]
 
 
 def modprobe( name ):
-	""" Try to import the named module, and if that works add it to INSTALLED_APPS. """
-	try:
-		__import__( name )
-	except ImportError:
-		pass
-	else:
-		INSTALLED_APPS.append( name )
+    """ Try to import the named module, and if that works add it to INSTALLED_APPS. """
+    try:
+        __import__( name )
+    except ImportError:
+        pass
+    else:
+        INSTALLED_APPS.append( name )
 
 # Check if rosetta is available.
 #    http://code.google.com/p/django-rosetta
